@@ -1,5 +1,7 @@
 package Perl::Critic::Policy::OTRS::RequireTrueReturnValueForModules;
 
+# ABSTRACT: Check if modules have a "true" return value
+
 use strict;
 use warnings;
 
@@ -8,7 +10,7 @@ use base 'Perl::Critic::Policy';
 
 use Readonly;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 Readonly::Scalar my $DESC => q{Modules have to return a true value ("1;")};
 Readonly::Scalar my $EXPL => q{Use "1;" as the last statement of the module};
@@ -29,8 +31,10 @@ sub violates {
 sub _returns_1 {
     my ( $self, $elem ) = @_;
     
-    my $last_statement = $elem->last_element( 'PPI::Statement' );
+    my $last_statement = ( grep{ ref $_ eq 'PPI::Statement' }$elem->schildren )[-1];
+    return 0 if !$last_statement;
     return 1 if $last_statement eq '1;';
+    return 0;
 }
 
 sub _is_script {
@@ -45,16 +49,17 @@ sub _is_script {
 }
 
 1;
+
 __END__
 =pod
 
 =head1 NAME
 
-Perl::Critic::Policy::OTRS::RequireTrueReturnValueForModules
+Perl::Critic::Policy::OTRS::RequireTrueReturnValueForModules - Check if modules have a "true" return value
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 AUTHOR
 
@@ -66,7 +71,7 @@ This software is Copyright (c) 2010 by Renee Baecker.
 
 This is free software, licensed under:
 
-  The Artistic License 2.0
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
 
